#!/usr/bin/env python3
# Mikey Garcia, @gikeymarcia
# https://github.com/gikeymarcia/pydymenu


class MissingProgram(Exception):
    """Exception raised when a required binary is missing from the system."""

    pass
